jBrout – Skupiny Google

## jBrout

Zobrazeno 1 - 20 z 543 témat

Work with Shotwell's ratings as well | mcepl | 9.12.13
[PATCH] Don't try to work with images in empty folder. | mcepl | 28.11.13
Multiusers on Jbrout and photos shared on a network drive | laur...@seor.fr | 22.10.13
open associated media plugin | Ennoia | 16.10.13
No Search button or Find menu | Zvonko Juras | 10.10.13
port to gexiv2 | Ennoia | 3.10.13
Some questions about tags and tagging | Chris | 23.9.13
I still have to comment out this line to prevent jbrout refusing to display - is it in the bugs list? | Chris | 23.9.13
Suggested patch for #206 | mcepl | 22.9.13
suggested fix for jbrout# 194? | mcepl | 22.9.13
[PATCH] Don't put categories into tags shown in full-screen view. | mcepl | 22.9.13
[PATCH] Add appdata file for better discoverability. | mcepl | 22.9.13
Re: subscribe jbr...@googlegroups.com | mcepl | 16.9.13
archive of the group? | mcepl | 15.9.13
test | mcepl | 14.9.13
SVN snapshot | Ennoia | 14.9.13
RFC: PEP8 branch to be merged on Monday | mcepl | 3.9.13
Feature request : "no tags" search option | Ennoia | 27.8.13
svg icon | Ennoia | 8.8.13
Help! | Franz | 15.7.13

Další témata »